"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CourseRecord = void 0;
const uuid_1 = require("uuid");
const errors_1 = require("../utils/errors");
const db_1 = require("../db/db");
class CourseRecord {
    constructor(obj) {
        var _a;
        if (obj.id) {
            if (obj.id.length !== 36) {
                throw new errors_1.ValidationError('Wrong format of id');
            }
        }
        if (!obj.name || obj.name.length > 100) {
            throw new errors_1.ValidationError('Course name should be between 1 and 100 characters long');
        }
        if (obj.description && obj.description.length > 1000) {
            throw new errors_1.ValidationError('Course description cannot be longer then 1000 characters');
        }
        if (!obj.startDate || !(obj.startDate instanceof Date)) {
            throw new errors_1.ValidationError('Course start date is obligatory and must be the Date');
        }
        if (obj.isActive === null) {
            throw new errors_1.ValidationError('isActive field must be clearly defined');
        }
        this.id = (_a = obj.id) !== null && _a !== void 0 ? _a : (0, uuid_1.v4)();
        this.name = obj.name;
        this.description = obj.description;
        this.startDate = obj.startDate;
        this.isActive = Boolean(Number(obj.isActive));
    }
    static getAll() {
        return __awaiter(this, void 0, void 0, function* () {
            const [foundCourses] = yield db_1.pool.execute("SELECT `id`, `name`, `description`, `isActive` from `courses` ORDER BY `name` ASC");
            return foundCourses.map(course => (Object.assign(Object.assign({}, course), { isActive: !!Number(course.isActive) })));
        });
    }
    static getOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [[course]] = yield db_1.pool.execute("SELECT * FROM `courses` WHERE id = :id", {
                id
            });
            return course ? new CourseRecord(course) : null;
        });
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute('INSERT INTO `courses` VALUES (:id, :name, :description, :startDate, :isActive)', {
                id: this.id,
                name: this.name,
                description: this.description,
                startDate: this.startDate,
                isActive: this.isActive,
            });
            return this.id;
        });
    }
    update() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute(' UPDATE `courses` SET isActive = :isActive WHERE id = :id', {
                id: this.id,
                isActive: !Number(this.isActive)
            });
            return {
                courseId: this.id,
                isChanged: 'ok'
            };
        });
    }
}
exports.CourseRecord = CourseRecord;
//# sourceMappingURL=course.record.js.map