"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.StudentRecord = void 0;
const errors_1 = require("../utils/errors");
const isEmail_1 = require("../utils/isEmail");
const uuid_1 = require("uuid");
const db_1 = require("../db/db");
const studentCourse_record_1 = require("./studentCourse.record");
class StudentRecord {
    constructor(obj) {
        var _a;
        if (obj.id) {
            if (typeof obj.id !== 'string' || obj.id.length !== 36) {
                throw new errors_1.ValidationError('Wrong format of id');
            }
        }
        if (!obj.firstName || obj.firstName.length > 15) {
            throw new errors_1.ValidationError('Student first name should be between 1 and 15 characters long');
        }
        if (!obj.lastName || obj.lastName.length > 35) {
            throw new errors_1.ValidationError('Student last name should be between 1 and 35 characters long');
        }
        if (!['male', 'female'].some(gender => gender === obj.gender)) {
            throw new errors_1.ValidationError('Wrong gender. Gender must equal "male" or "female" ');
        }
        if (!obj.dateOfBirth || !(obj.dateOfBirth instanceof Date)) {
            throw new errors_1.ValidationError('Date of birth is obligatory and must be the Date');
        }
        if (obj.dateOfBirth > new Date(new Date().valueOf() - 18 * 31556952000)) {
            throw new errors_1.ValidationError('Student is underage');
        }
        if (!obj.emailAddress || !(0, isEmail_1.isEmail)(obj.emailAddress)) {
            throw new errors_1.ValidationError('Invalid email Address');
        }
        this.id = (_a = obj.id) !== null && _a !== void 0 ? _a : (0, uuid_1.v4)();
        this.firstName = obj.firstName;
        this.lastName = obj.lastName;
        this.gender = obj.gender;
        this.dateOfBirth = obj.dateOfBirth;
        this.emailAddress = obj.emailAddress;
    }
    static getAll() {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT `id`, `firstName`, `lastName` FROM `students` ORDER BY `lastName` ASC");
            return results;
        });
    }
    static getOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [[student]] = yield db_1.pool.execute("SELECT * FROM `students` WHERE id = :id", {
                id
            });
            return student ? new StudentRecord(student) : null;
        });
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("INSERT INTO `students` VALUES (:id, :firstName, :lastName, :gender, :dateOfBirth, :emailAddress)", this);
            return this.id;
        });
    }
    static getBirthdayStudents() {
        return __awaiter(this, void 0, void 0, function* () {
            const [birthdayStudents] = yield db_1.pool.execute("SELECT `id`, `firstName`, `lastName` FROM `students` WHERE DAY(dateOfBirth) = DAY(curdate()) AND MONTH(dateOfBirth) = MONTH(curdate())");
            return birthdayStudents;
        });
    }
    delete() {
        return __awaiter(this, void 0, void 0, function* () {
            const courses = yield studentCourse_record_1.StudentCourseRecord.getCoursesOfStudents(this.id);
            const coursesIds = courses.map(course => course.id);
            for (const coursesId of coursesIds) {
                yield studentCourse_record_1.StudentCourseRecord.delete(coursesId);
            }
            yield db_1.pool.execute("DELETE FROM `students` WHERE id = :id", {
                id: this.id
            });
        });
    }
}
exports.StudentRecord = StudentRecord;
//# sourceMappingURL=student.record.js.map