"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.StudentCourseRecord = void 0;
const uuid_1 = require("uuid");
const db_1 = require("../db/db");
const errors_1 = require("../utils/errors");
class StudentCourseRecord {
    constructor(obj) {
        if (obj.studentId.length !== 36 || obj.courseId.length !== 36) {
            throw new errors_1.ValidationError('Wrong studentID or courseId format');
        }
        this.courseId = obj.courseId;
        this.studentId = obj.studentId;
    }
    static getCoursesOfStudents(studentId) {
        return __awaiter(this, void 0, void 0, function* () {
            const [coursesOfStudents] = yield db_1.pool.execute("SELECT stc.id, stc.courseId, crs.name FROM `studentCourses` as stc LEFT JOIN `courses` AS crs ON crs.id = stc.courseId WHERE stc.studentId = :studentId AND crs.isActive = true", {
                studentId
            });
            return coursesOfStudents;
        });
    }
    static getParticipantsOfCourse(courseId) {
        return __awaiter(this, void 0, void 0, function* () {
            const [participants] = yield db_1.pool.execute("SELECT stc.id, stc.studentId, stn.firstName, stn.lastName FROM `studentCourses` as stc LEFT JOIN `students` AS stn ON stn.id = stc.studentId WHERE stc.courseId = :courseId ORDER BY stn.lastName ASC ", {
                courseId
            });
            return participants;
        });
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id) {
                this.id = (0, uuid_1.v4)();
            }
            if ((yield StudentCourseRecord.getCoursesOfStudents(this.studentId)).some((studentCourse) => studentCourse.courseId === this.courseId)) {
                throw new errors_1.ValidationError('The Student has been already sign on this course');
            }
            yield db_1.pool.execute("INSERT INTO `studentCourses` VALUES (:id, :studentId, :courseId)", {
                id: this.id,
                studentId: this.studentId,
                courseId: this.courseId,
            });
            return this.id;
        });
    }
    static delete(studentCourseID) {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("DELETE FROM `studentCourses` WHERE id = :studentCourseID", {
                studentCourseID
            });
        });
    }
}
exports.StudentCourseRecord = StudentCourseRecord;
//# sourceMappingURL=studentCourse.record.js.map