"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserRecord = void 0;
const errors_1 = require("../utils/errors");
const isEmail_1 = require("../utils/isEmail");
const db_1 = require("../db/db");
class UserRecord {
    constructor(user) {
        if (user.id) {
            if (typeof user.id !== 'string' || user.id.length !== 36) {
                throw new errors_1.ValidationError('Wrong format of id');
            }
        }
        if (!user.email || !(0, isEmail_1.isEmail)(user.email)) {
            throw new errors_1.ValidationError('Invalid email Address');
        }
        if (!user.password) {
            throw new errors_1.ValidationError('Password is obligatory ');
        }
        this.id = user.id;
        this.email = user.email;
        this.password = user.password;
        this.currentToken = user.currentToken;
    }
    static getOneByCredentials(email, password) {
        return __awaiter(this, void 0, void 0, function* () {
            const [[user]] = yield db_1.pool.execute("SELECT * FROM `users` WHERE email = :email AND password = :password", {
                email: email,
                password: password
            });
            return user ? new UserRecord(user) : null;
        });
    }
    static getOneById(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [[user]] = yield db_1.pool.execute("SELECT * FROM `users` WHERE id = :id", {
                id: id
            });
            return user ? new UserRecord(user) : null;
        });
    }
    updateToken(token = null) {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("UPDATE `users` SET `currentToken` = :token WHERE id = :id", {
                id: this.id,
                token: token
            });
        });
    }
}
exports.UserRecord = UserRecord;
//# sourceMappingURL=user.record.js.map