"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.studentRouter = void 0;
const express_1 = require("express");
const student_record_1 = require("../records/student.record");
const isDate_1 = require("../utils/isDate");
const errors_1 = require("../utils/errors");
exports.studentRouter = (0, express_1.Router)();
exports.studentRouter
    .get('/', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    res.json(yield student_record_1.StudentRecord.getAll());
}))
    .get('/birthday-students', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    res.json(yield student_record_1.StudentRecord.getBirthdayStudents());
}))
    .get('/:id', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const { id } = req.params;
    res.json(yield student_record_1.StudentRecord.getOne(id));
}))
    .post('/', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    if (!(0, isDate_1.isDate)(req.body.dateOfBirth)) {
        throw new errors_1.ValidationError('Start Date must be a Date type');
    }
    const newStudent = new student_record_1.StudentRecord(Object.assign(Object.assign({}, req.body), { dateOfBirth: new Date(req.body.dateOfBirth) }));
    res.status(201);
    res.json(yield newStudent.insert());
}))
    .delete('/:id', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const { id } = req.params;
    const student = yield student_record_1.StudentRecord.getOne(id);
    if (!student) {
        throw new errors_1.ValidationError('There is no such student');
    }
    yield student.delete();
    res.status(204);
    res.end();
}));
//# sourceMappingURL=student.router.js.map