"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Auth = void 0;
const jsonwebtoken_1 = __importDefault(require("jsonwebtoken"));
const config_1 = require("../config/config");
const errors_1 = require("../utils/errors");
const hash_pwd_1 = require("../utils/hash-pwd");
const user_record_1 = require("../records/user.record");
class Auth {
    static login(user) {
        return __awaiter(this, void 0, void 0, function* () {
            const foundUser = yield user_record_1.UserRecord.getOneByCredentials(user.email, (0, hash_pwd_1.hashPwd)(user.password));
            if (!foundUser)
                throw new errors_1.ValidationError('Wrong login and password');
            const accessToken = jsonwebtoken_1.default.sign({ id: foundUser.id }, config_1.config.tokenSecret, {
                expiresIn: '1h'
            });
            yield foundUser.updateToken(accessToken);
            return accessToken;
        });
    }
    static logout(token) {
        return __awaiter(this, void 0, void 0, function* () {
            const payload = yield jsonwebtoken_1.default.verify(token, config_1.config.tokenSecret);
            const foundUser = yield user_record_1.UserRecord.getOneById(payload.id);
            yield foundUser.updateToken();
        });
    }
}
exports.Auth = Auth;
//# sourceMappingURL=Auth.js.map