"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.defaultCourse = void 0;
const course_record_1 = require("../../records/course.record");
beforeAll(() => {
    exports.defaultCourse = new course_record_1.CourseRecord({
        name: 'Kizomba od podstaw',
        description: 'Testowy opis kursu',
        startDate: new Date(),
        isActive: true,
    });
});
test('Can build Course Record', () => {
    expect(exports.defaultCourse.id).toBeDefined();
    expect(exports.defaultCourse.name).toEqual('Kizomba od podstaw');
    expect(exports.defaultCourse.startDate instanceof Date).toBeTruthy();
    expect(exports.defaultCourse.isActive).toBeTruthy();
});
test('Validates invalid id', () => {
    expect(() => new course_record_1.CourseRecord(Object.assign(Object.assign({}, exports.defaultCourse), { id: 'abc' }))).toThrow();
    expect(() => new course_record_1.CourseRecord(Object.assign(Object.assign({}, exports.defaultCourse), { id: undefined }))).not.toThrow('Wrong format of id');
});
test('Validates invalid name', () => {
    expect(() => new course_record_1.CourseRecord(Object.assign(Object.assign({}, exports.defaultCourse), { name: undefined }))).toThrow('Course name should be between 1 and 100 characters long');
    expect(() => new course_record_1.CourseRecord(Object.assign(Object.assign({}, exports.defaultCourse), { name: 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.' }))).toThrow('Course name should be between 1 and 100 characters long');
});
test('Validates invalid description', () => {
    expect(() => new course_record_1.CourseRecord(Object.assign(Object.assign({}, exports.defaultCourse), { description: 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.' }))).toThrow('Course description cannot be longer then 1000 characters');
});
test('Validates invalid start date', () => {
    expect(() => new course_record_1.CourseRecord(Object.assign(Object.assign({}, exports.defaultCourse), { startDate: undefined }))).toThrow('Course start date is obligatory and must be the Date');
    expect(() => new course_record_1.CourseRecord(Object.assign(Object.assign({}, exports.defaultCourse), { startDate: '2023-11-23' }))).toThrow('Course start date is obligatory and must be the Date');
});
test('Validates invalid activity', () => {
    expect(() => new course_record_1.CourseRecord(Object.assign(Object.assign({}, exports.defaultCourse), { isActive: null }))).toThrow('isActive field must be clearly defined');
});
//# sourceMappingURL=course-record.test.js.map