"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const course_record_1 = require("../../records/course.record");
const uuid_1 = require("uuid");
const course_record_test_1 = require("./course-record.test");
let course;
beforeAll(() => {
    course = new course_record_1.CourseRecord(course_record_test_1.defaultCourse);
});
jest
    .spyOn(course_record_1.CourseRecord, "getOne")
    .mockImplementation((id) => __awaiter(void 0, void 0, void 0, function* () {
    if (id === 'xyz') {
        return null;
    }
    else {
        return new course_record_1.CourseRecord({
            id,
            name: 'Kizomba w Ritmo',
            description: 'Taniec, który swoje korzenie wypuścił z Angoli, a które dotarły aż do Ritmo! Mówi się, że kizomba to najpiękniejszy sposób na przytulenie drugiego człowieka. Jest językiem ciała, pełnym czułości, bliskości. Skupia się na partnerach i emocjach pomiędzy nimi, dzięki czemu będziecie mieli okazję przekazać to, czego nie da się wyrazić choćby tysiącem słów. Podbije Wasze serca swoją prostotą i elegancją, wzmocni pewność siebie i kto wie? Może wciągnie tak samo jak nas? Słowem - petarda!',
            startDate: new Date(),
            isActive: true,
        });
    }
}));
jest
    .spyOn(course_record_1.CourseRecord, 'getAll')
    .mockImplementation(() => __awaiter(void 0, void 0, void 0, function* () {
    return ([
        {
            id: "c3ac6512-1191-4f4a-a9eb-98bb3cc0c80d",
            name: "Bachata",
            description: 'opis',
            isActive: true
        },
        {
            id: "c3ddec32-aed3-46d8-9995-96b1002ed8c8",
            name: "Bachata",
            description: "Bliski kontakt partnerów, zmysłowy ruch bioder, romantyczna muzyka … To wszystko sprawia, że kiedy raz zatańczysz bachatę – nie możesz już przestać tańczyć. Na kursie nauczysz się kroków podstawowych, obrotów a także wielu innych podstawowych elementów tańca w parze tj. contra, slide, wychylenia, techniki prowadzenia partnerki oraz ruch bioder. Jeśli tańczysz salsę i bywasz na latynoskich imprezach, a jeszcze nie umiesz tańczyć bachaty …to najwyższy czas nadrobić tę zaległość!\r\n\r\nNasi instruktorzy bachaty (zawsze jest to para!) – wprowadzą Cię w ten rewelacyjny taniec!\r\nJeśli chcesz brać udział w salsotekach, nauka bachaty będzie najprostszą i najmilszą na nie przepustką. Kurs polecany dla osób, które pragną wynieść z zajęć niezapomniane wrażenia, a także dla tych, które chcą dobrze się bawić w rytmach gorącej muzyki.\r\n\r\nPolecamy ten taniec wszystkim pragnącym nauki prostego, ale bardzo zmysłowego tańca !",
            isActive: false
        },
    ]);
}));
jest
    .spyOn(course_record_1.CourseRecord.prototype, 'insert')
    .mockImplementation(() => __awaiter(void 0, void 0, void 0, function* () {
    return (0, uuid_1.v4)();
}));
test('CourseRecord.getOne() returns data from db for existing record', () => __awaiter(void 0, void 0, void 0, function* () {
    const course = yield course_record_1.CourseRecord.getOne('39f5d124-6d7f-4c6b-9f1f-3afe30cae7ae');
    expect(course.id).toEqual('39f5d124-6d7f-4c6b-9f1f-3afe30cae7ae');
    expect(course.name).toEqual('Kizomba w Ritmo');
    expect(course.description).toBeDefined();
    expect(course.startDate instanceof Date).toBeTruthy();
    expect(course.isActive).toEqual(true);
}));
test('CourseRecord.getOne() returns null for no existing record', () => __awaiter(void 0, void 0, void 0, function* () {
    const course = yield course_record_1.CourseRecord.getOne('xyz');
    expect(course).toBeNull();
}));
test('CourseRecord.insert() returns id in uuid format', () => __awaiter(void 0, void 0, void 0, function* () {
    expect(yield course.insert()).toBeDefined();
    expect(yield course.insert()).toMatch(/^[0-9A-F]{8}-[0-9A-F]{4}-[4][0-9A-F]{3}-[89AB][0-9A-F]{3}-[0-9A-F]{12}$/i);
}));
test('CourseRecord.getAll returns array of SimpleCourseEntities', () => __awaiter(void 0, void 0, void 0, function* () {
    const courses = yield course_record_1.CourseRecord.getAll();
    expect(courses).toHaveLength(2);
    expect(courses[0].id).toBeDefined();
    expect(courses[0].name).toEqual('Bachata');
    expect(courses[0].description).toBeDefined();
    expect(typeof courses[0].isActive === 'boolean').toBeTruthy();
}));
//# sourceMappingURL=course.test.js.map