"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const Stats_1 = require("../../services/Stats");
const course_record_1 = require("../../records/course.record");
const db_1 = require("../../db/db");
const student_record_1 = require("../../records/student.record");
let activeCoursesRes;
let activeStudentsRes;
beforeAll(() => __awaiter(void 0, void 0, void 0, function* () {
    activeCoursesRes = yield Stats_1.Stats.getNumberOfActiveCourses();
    activeStudentsRes = yield Stats_1.Stats.getActiveStudentsNumber();
}));
afterAll(() => __awaiter(void 0, void 0, void 0, function* () {
    yield db_1.pool.end();
}));
jest
    .spyOn(Stats_1.Stats, 'getTotalAvgFrequency')
    .mockImplementation(() => __awaiter(void 0, void 0, void 0, function* () {
    return {
        avgFrequency: 100 / 10
    };
}));
test('getNumberOfActiveCourses() returns number', () => __awaiter(void 0, void 0, void 0, function* () {
    expect(activeCoursesRes).toHaveProperty('coursesNumber');
    expect(activeCoursesRes instanceof Object).toBeTruthy();
    expect(typeof activeCoursesRes.coursesNumber === 'number').toBeTruthy();
}));
test('getNumberOfActiveCourses() returns potentially correct data', () => __awaiter(void 0, void 0, void 0, function* () {
    expect(activeCoursesRes.coursesNumber).not.toBeGreaterThan((yield course_record_1.CourseRecord.getAll()).length);
    const activeCourses = (yield course_record_1.CourseRecord.getAll()).filter(course => course.isActive === true);
    expect(activeCoursesRes.coursesNumber).toEqual(activeCourses.length);
}));
test('getActiveStudentsNumber() returns number', () => __awaiter(void 0, void 0, void 0, function* () {
    expect(activeStudentsRes).toHaveProperty('studentsNumber');
    expect(activeStudentsRes instanceof Object).toBeTruthy();
    expect(typeof activeStudentsRes.studentsNumber === 'number').toBeTruthy();
}));
test('getActiveStudentsNumber() returns potentially correct data', () => __awaiter(void 0, void 0, void 0, function* () {
    expect(activeStudentsRes.studentsNumber).not.toBeGreaterThan((yield student_record_1.StudentRecord.getAll()).length);
}));
test('getTotalAvgFrequency() return correct data', () => __awaiter(void 0, void 0, void 0, function* () {
    const response = yield Stats_1.Stats.getTotalAvgFrequency();
    expect(response).toHaveProperty('avgFrequency');
    expect(typeof response.avgFrequency === 'number').toBeTruthy();
    expect(response.avgFrequency).toEqual(100 / 10);
}));
//# sourceMappingURL=stats.test.js.map