"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.defaultStudent = void 0;
const student_record_1 = require("../../records/student.record");
beforeAll(() => {
    exports.defaultStudent = new student_record_1.StudentRecord({
        firstName: 'Jan',
        lastName: 'Kowalski',
        gender: 'male',
        dateOfBirth: new Date('2000-11-12'),
        emailAddress: 'jan.kowal@a.b'
    });
});
test('Can build StudentRecord', () => {
    expect(exports.defaultStudent.id).toBeDefined();
    expect(exports.defaultStudent.id.length).toEqual(36);
    expect(exports.defaultStudent.firstName).toEqual('Jan');
    expect(exports.defaultStudent.lastName).toEqual('Kowalski');
    expect(exports.defaultStudent.gender).toBe('male');
    expect(exports.defaultStudent.dateOfBirth instanceof Date).toBeTruthy();
    expect(exports.defaultStudent.emailAddress).toBe('jan.kowal@a.b');
});
test('Validates invalid id', () => {
    expect(() => new student_record_1.StudentRecord(Object.assign(Object.assign({}, exports.defaultStudent), { id: 123 }))).toThrow();
    expect(() => new student_record_1.StudentRecord(Object.assign(Object.assign({}, exports.defaultStudent), { id: 'ssdass' }))).toThrow();
});
test('Validates invalid first name', () => {
    expect(() => new student_record_1.StudentRecord(Object.assign(Object.assign({}, exports.defaultStudent), { firstName: '' }))).toThrow();
    expect(() => new student_record_1.StudentRecord(Object.assign(Object.assign({}, exports.defaultStudent), { firstName: 'Bardzo długie imię i nawet zbyt długie' }))).toThrow();
    expect(() => new student_record_1.StudentRecord(Object.assign(Object.assign({}, exports.defaultStudent), { firstName: undefined }))).toThrow();
});
test('Validates invalid last name', () => {
    expect(() => new student_record_1.StudentRecord(Object.assign(Object.assign({}, exports.defaultStudent), { lastName: undefined }))).toThrow();
    expect(() => new student_record_1.StudentRecord(Object.assign(Object.assign({}, exports.defaultStudent), { lastName: '' }))).toThrow();
    expect(() => new student_record_1.StudentRecord(Object.assign(Object.assign({}, exports.defaultStudent), { lastName: 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.' }))).toThrow();
});
test('Validates invalid gender', () => {
    expect(() => new student_record_1.StudentRecord(Object.assign(Object.assign({}, exports.defaultStudent), { gender: 'woman' }))).toThrow();
    expect(() => new student_record_1.StudentRecord(Object.assign(Object.assign({}, exports.defaultStudent), { gender: undefined }))).toThrow();
});
test('Validates invalid date of Birth', () => {
    expect(() => new student_record_1.StudentRecord(Object.assign(Object.assign({}, exports.defaultStudent), { dateOfBirth: '2021-11-11' }))).toThrow();
    expect(() => new student_record_1.StudentRecord(Object.assign(Object.assign({}, exports.defaultStudent), { dateOfBirth: 'yesterday' }))).toThrow();
    expect(() => new student_record_1.StudentRecord(Object.assign(Object.assign({}, exports.defaultStudent), { dateOfBirth: new Date('2015-11-01') }))).toThrow();
});
test('Validates invalid email address', () => {
    expect(() => new student_record_1.StudentRecord(Object.assign(Object.assign({}, exports.defaultStudent), { emailAddress: 'something' }))).toThrow();
    expect(() => new student_record_1.StudentRecord(Object.assign(Object.assign({}, exports.defaultStudent), { emailAddress: 'something@.abc.com' }))).not.toThrow();
});
//# sourceMappingURL=student-record.test.js.map