"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const student_record_1 = require("../../records/student.record");
const student_record_test_1 = require("./student-record.test");
const db_1 = require("../../db/db");
let newStudent;
beforeAll(() => {
    newStudent = new student_record_1.StudentRecord({
        firstName: 'Zenon',
        lastName: `${student_record_test_1.defaultStudent.lastName}[TEST]`,
        gender: 'male',
        dateOfBirth: new Date('2000-01-01'),
        emailAddress: 'a@.b.c'
    });
});
afterAll(() => __awaiter(void 0, void 0, void 0, function* () {
    yield db_1.pool.execute("DELETE FROM `students` WHERE `lastName` like '%[TEST]%'");
    yield db_1.pool.end();
}));
test('StudentRecord.insert() returns id', () => __awaiter(void 0, void 0, void 0, function* () {
    const insertedId = yield newStudent.insert();
    expect(insertedId).toHaveLength(36);
    expect(insertedId).toMatch(/^[0-9A-F]{8}-[0-9A-F]{4}-[4][0-9A-F]{3}-[89AB][0-9A-F]{3}-[0-9A-F]{12}$/i);
}));
test('StudentRecord.insert() inserts record to db and StudentRecord.getOne() returns record from db', () => __awaiter(void 0, void 0, void 0, function* () {
    const newStudent = new student_record_1.StudentRecord(Object.assign(Object.assign({}, student_record_test_1.defaultStudent), { lastName: `${student_record_test_1.defaultStudent.lastName}[TEST]` }));
    const insertedId = yield newStudent.insert();
    const foundStudent = yield student_record_1.StudentRecord.getOne(insertedId);
    expect(foundStudent).toBeDefined();
    expect(foundStudent.id).toEqual(newStudent.id);
    expect(foundStudent).toStrictEqual(newStudent);
}));
test('StudentsRecord.getOne() returns null for no existing id', () => __awaiter(void 0, void 0, void 0, function* () {
    const found = yield student_record_1.StudentRecord.getOne('xyz');
    expect(found).toBeNull();
}));
test('StudentsRecord.getAll() returns array of records', () => __awaiter(void 0, void 0, void 0, function* () {
    const results = yield student_record_1.StudentRecord.getAll();
    expect(results instanceof Array).toBeTruthy();
    expect(results.length).toBeGreaterThanOrEqual(1);
    expect(results[0] instanceof student_record_1.StudentRecord).not.toBeTruthy();
}));
//# sourceMappingURL=student.test.js.map