"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const db_1 = require("../../db/db");
const studentCourse_record_1 = require("../../records/studentCourse.record");
const course_record_1 = require("../../records/course.record");
const student_record_1 = require("../../records/student.record");
let insertedId;
let exampleCourseId;
let exampleStudentId;
let myStudentCourseRecord;
beforeAll(() => __awaiter(void 0, void 0, void 0, function* () {
    exampleCourseId = (yield course_record_1.CourseRecord.getAll())[0].id;
    exampleStudentId = (yield student_record_1.StudentRecord.getAll())[0].id;
    myStudentCourseRecord = new studentCourse_record_1.StudentCourseRecord({
        courseId: exampleCourseId,
        studentId: exampleStudentId
    });
}));
afterAll(() => __awaiter(void 0, void 0, void 0, function* () {
    console.log(insertedId);
    yield db_1.pool.execute("DELETE FROM `studentCourses` WHERE id = :id", {
        id: insertedId
    });
    yield db_1.pool.end();
}));
test('insert() returns id as uuid', () => __awaiter(void 0, void 0, void 0, function* () {
    insertedId = yield myStudentCourseRecord.insert();
    expect(insertedId).toBeDefined();
    expect(insertedId).toMatch(/^[0-9A-F]{8}-[0-9A-F]{4}-[4][0-9A-F]{3}-[89AB][0-9A-F]{3}-[0-9A-F]{12}$/i);
}));
test('Second try to insert the same record should Throw', () => __awaiter(void 0, void 0, void 0, function* () {
    const nextStudentCourseRecord = new studentCourse_record_1.StudentCourseRecord({
        courseId: myStudentCourseRecord.courseId,
        studentId: myStudentCourseRecord.studentId,
    });
    yield expect(nextStudentCourseRecord.insert()).rejects.toThrow();
}));
test('getCoursesOfStudents() returns list of courses', () => __awaiter(void 0, void 0, void 0, function* () {
    const coursesOfStudent = yield studentCourse_record_1.StudentCourseRecord.getCoursesOfStudents(exampleStudentId);
    expect(coursesOfStudent).toBeDefined();
    expect(coursesOfStudent.length).toBeGreaterThanOrEqual(1);
    expect(coursesOfStudent[0]).toHaveProperty('id');
    expect(coursesOfStudent[0]).toHaveProperty('courseId');
    expect(coursesOfStudent[0]).toHaveProperty('name');
}));
test('getParticipantsOfCourse() returns list of participants', () => __awaiter(void 0, void 0, void 0, function* () {
    const participantsList = yield studentCourse_record_1.StudentCourseRecord.getParticipantsOfCourse(exampleCourseId);
    expect(participantsList).toBeDefined();
    expect(participantsList.length).toBeGreaterThanOrEqual(1);
    expect(participantsList[0]).toHaveProperty('id');
    expect(participantsList[0]).toHaveProperty('studentId');
    expect(participantsList[0]).toHaveProperty('firstName');
    expect(participantsList[0]).toHaveProperty('lastName');
}));
//# sourceMappingURL=studentCourse.test.js.map